pub enum TcpType {
Active,
Passive,
So,
}Expand description
TCP connection role as defined by the tcptype SDP attribute.
This enum corresponds to the TCP connection setup modes defined in RFC 6544 4.5, which specifies how endpoints establish TCP connections when TCP is used as a transport for media streams.
Variants
Active
The endpoint actively initiates the TCP connection.
In this mode, the endpoint performs an active open (i.e., sends a SYN) to the remote peer.
Passive
The endpoint passively waits for an incoming TCP connection.
In this mode, the endpoint performs a passive open (i.e., listens) and accepts a connection initiated by the remote peer.
So
Simultaneous open.
Both endpoints attempt to actively open a TCP connection to each other at the same time. This relies on TCP simultaneous open behavior.