pub struct Transmit {
pub proto: Protocol,
pub source: SocketAddr,
pub destination: SocketAddr,
pub contents: DatagramSend,
}Expand description
An instruction to send an outgoing packet.
Fields
proto: ProtocolProtocol the transmission should use.
source: SocketAddrThe source IP this packet should be sent from.
For ICE it’s important to send outgoing packets from the correct IP address. The IP could come from a local socket or relayed over a TURN server. Features like hole-punching will only work if the packets are routed through the correct interfaces.
destination: SocketAddrThe destination address this datagram should be sent to.
contents: DatagramSendContents of the datagram.